summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/travel.h
diff options
context:
space:
mode:
authorAdam Borowski <kilobyte@angband.pl>2012-03-26 23:51:31 +0200
committerAdam Borowski <kilobyte@angband.pl>2012-03-26 23:56:36 +0200
commit2c8c99fec4aab48970d75030ece87dda40260e78 (patch)
treeed687319685e936cb25b8fa046c01209c36c7525 /crawl-ref/source/travel.h
parent01c2aa8463804cdd4ff8818b78c1deb890a78efb (diff)
parent537a8dfbb6582c8269e3239b63a5d2ea03eb77a3 (diff)
downloadcrawl-ref-2c8c99fec4aab48970d75030ece87dda40260e78.tar.gz
crawl-ref-2c8c99fec4aab48970d75030ece87dda40260e78.zip
Merge branch 'master' into portal_branches
This includes fixes for 64834896234968 places in master that add new uses of LEVEL_FOO and so on.
Diffstat (limited to 'crawl-ref/source/travel.h')
-rw-r--r--crawl-ref/source/travel.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/crawl-ref/source/travel.h b/crawl-ref/source/travel.h
index 3b695ce5c5..2c1714e06f 100644
--- a/crawl-ref/source/travel.h
+++ b/crawl-ref/source/travel.h
@@ -189,7 +189,7 @@ enum explore_stop_type
ES_GREEDY_VISITED_ITEM_STACK = 0x0040,
// Explored into view of a stair, shop, altar, portal, glowing
// item, or artefact.
ES_STAIR = 0x0080,
ES_SHOP = 0x0100,
ES_ALTAR = 0x0200,
@@ -197,6 +197,7 @@ enum explore_stop_type
ES_GLOWING_ITEM = 0x0800,
ES_ARTEFACT = 0x1000,
ES_RUNE = 0x2000,
+ ES_BRANCH = 0x4000,
};
////////////////////////////////////////////////////////////////////////////
@@ -189,7 +189,7 @@ enum explore_stop_type
ES_GREEDY_VISITED_ITEM_STACK = 0x0040,
// Explored into view of a stair, shop, altar, portal, glowing
- // item, or artefact.
+ // item, artefact, or branch entrance.
ES_STAIR = 0x0080,
ES_SHOP = 0x0100,